@@ -19,8 +19,11 @@ from localstack.aws.api import (
     handler,
 )
 from localstack.aws.api.dynamodb import (
+    BatchGetItemOutput,
+    BatchGetRequestMap,
     BatchWriteItemInput,
     BatchWriteItemOutput,
+    BillingMode,
     CreateGlobalTableOutput,
     CreateTableInput,
     CreateTableOutput,
@@ -56,6 +59,7 @@ from localstack.aws.api.dynamodb import (
     ResourceArnString,
     ResourceInUseException,
     ResourceNotFoundException,
+    ReturnConsumedCapacity,
     ScanInput,
     ScanOutput,
     StreamArn,
@@ -383,6 +387,13 @@ class DynamoDBProvider(DynamodbApi, ServiceLifecycleHook):
         table_name = create_table_input["TableName"]
         if self.table_exists(table_name):
             raise ResourceInUseException("Cannot create preexisting table")
+        billing_mode = create_table_input.get("BillingMode")
+        provisioned_throughput = create_table_input.get("ProvisionedThroughput")
+        if billing_mode == BillingMode.PAY_PER_REQUEST and provisioned_throughput is not None:
+            raise ValidationException(
+                "One or more parameter values were invalid: Neither ReadCapacityUnits nor WriteCapacityUnits can be "
+                "specified when BillingMode is PAY_PER_REQUEST"
+            )
 
         # forward request to backend
         result = self.forward_request(context)
@@ -710,6 +721,15 @@ class DynamoDBProvider(DynamodbApi, ServiceLifecycleHook):
 
         return result
 
+    @handler("BatchGetItem")
+    def batch_get_item(
+        self,
+        context: RequestContext,
+        request_items: BatchGetRequestMap,
+        return_consumed_capacity: ReturnConsumedCapacity = None,
+    ) -> BatchGetItemOutput:
+        return self.forward_request(context)
+
     @handler("TransactWriteItems", expand=False)
     def transact_write_items(
         self,
@@ -1225,9 +1245,19 @@ def get_global_secondary_index(table_name, index_name):
     raise ResourceNotFoundException("Index not found")
 
 
+def is_local_secondary_index(table_name, index_name) -> bool:
+    schema = SchemaExtractor.get_table_schema(table_name)
+    for index in schema["Table"].get("LocalSecondaryIndexes", []):
+        if index["IndexName"] == index_name:
+            return True
+    return False
+
+
 def is_index_query_valid(query_data: dict) -> bool:
     table_name = to_str(query_data["TableName"])
     index_name = to_str(query_data["IndexName"])
+    if is_local_secondary_index(table_name, index_name):
+        return True
     index_query_type = query_data.get("Select")
     index = get_global_secondary_index(table_name, index_name)
     index_projection_type = index.get("Projection").get("ProjectionType")
