@@ -268,8 +268,8 @@ class SecretsmanagerProvider(SecretsmanagerApi):
 
 
 @patch(FakeSecret.__init__)
-def fake_secret__init__(fn, self, **kwargs):
-    fn(self, **kwargs)
+def fake_secret__init__(fn, self, *args, **kwargs):
+    fn(self, *args, **kwargs)
 
     # Fix time not including millis.
     time_now = time.time()
