@@ -267,6 +267,27 @@ def connect_to_resource(
     )
 
 
+def connect_to_resource_external(
+    service_name,
+    env=None,
+    region_name=None,
+    endpoint_url=None,
+    config: botocore.config.Config = None,
+    **kwargs,
+):
+    """
+    Generic method to obtain an AWS service resource using boto3, based on environment, region, or custom endpoint_url.
+    """
+    return create_external_boto_client(
+        service_name,
+        client=False,
+        env=env,
+        region_name=region_name,
+        endpoint_url=endpoint_url,
+        config=config,
+    )
+
+
 def connect_to_service(
     service_name,
     client=True,
@@ -845,10 +866,9 @@ def mock_aws_request_headers(service="dynamodb", region_name=None, access_key=No
         "X-Amz-Date": "20160623T103251Z",
         "Authorization": (
             "AWS4-HMAC-SHA256 "
-            + "Credential=%s/20160623/%s/%s/aws4_request, "
+            + f"Credential={access_key}/20160623/{region_name}/{service}/aws4_request, "
             + "SignedHeaders=content-type;host;x-amz-date;x-amz-target, Signature=1234"
-        )
-        % (access_key, region_name, service),
+        ),
     }
     return headers
 
